@@ -47,15 +47,16 @@ struct _AlsaBackendPrivate
     GHashTable *devices_ids;
 };
 
-static void alsa_backend_class_init     (AlsaBackendClass *klass);
-static void alsa_backend_class_finalize (AlsaBackendClass *klass);
-static void alsa_backend_init           (AlsaBackend      *alsa);
 static void alsa_backend_dispose        (GObject          *object);
 static void alsa_backend_finalize       (GObject          *object);
 
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wunused-function"
-G_DEFINE_DYNAMIC_TYPE (AlsaBackend, alsa_backend, MATE_MIXER_TYPE_BACKEND)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (AlsaBackend,
+                                alsa_backend,
+                                MATE_MIXER_TYPE_BACKEND,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC(AlsaBackend))
 #pragma clang diagnostic pop
 
 static gboolean     alsa_backend_open            (MateMixerBackend *backend);
@@ -125,8 +126,6 @@ alsa_backend_class_init (AlsaBackendClass *klass)
     backend_class->close        = alsa_backend_close;
     backend_class->list_devices = alsa_backend_list_devices;
     backend_class->list_streams = alsa_backend_list_streams;
-
-    g_type_class_add_private (object_class, sizeof (AlsaBackendPrivate));
 }
 
 /* Called in the code generated by G_DEFINE_DYNAMIC_TYPE() */
@@ -138,9 +137,7 @@ alsa_backend_class_finalize (AlsaBackendClass *klass)
 static void
 alsa_backend_init (AlsaBackend *alsa)
 {
-    alsa->priv = G_TYPE_INSTANCE_GET_PRIVATE (alsa,
-                                             ALSA_TYPE_BACKEND,
-                                             AlsaBackendPrivate);
+    alsa->priv = alsa_backend_get_instance_private (alsa);
 
     alsa->priv->devices_ids = g_hash_table_new_full (g_str_hash,
                                                      g_str_equal,
@@ -314,14 +311,16 @@ read_device (AlsaBackend *alsa, const gchar *card)
     const gchar         *id;
     gint                 ret;
 
-    /* The device may be already known, remove it if it's known and fails
-     * to be read, this happens for example when PulseAudio is killed */
+    /*
+     * The device may be already known.
+     *
+     * Make sure it is removed from the list of devices if it fails to be
+     * read. This commonly happens with the "default" device, which is not
+     * reassigned by ALSA when the sound card is removed or the sound mixer
+     * quits.
+    */
     ret = snd_ctl_open (&ctl, card, 0);
     if (ret < 0) {
-        g_warning ("Failed to open ALSA control for %s: %s",
-                   card,
-                   snd_strerror (ret));
-
         remove_device_by_name (alsa, card);
         return FALSE;
     }
@@ -433,17 +432,23 @@ remove_device_by_list_item (AlsaBackend *alsa, GList *item)
 
     device = ALSA_DEVICE (item->data);
 
-    g_signal_handlers_disconnect_by_data (G_OBJECT (device), alsa);
+    g_signal_handlers_disconnect_by_func (G_OBJECT (device),
+                                          G_CALLBACK (remove_device),
+                                          alsa);
 
+    /* May emit removed signals */
     if (alsa_device_is_open (device) == TRUE)
         alsa_device_close (device);
 
+    g_signal_handlers_disconnect_by_data (G_OBJECT (device),
+                                          alsa);
+
     alsa->priv->devices = g_list_delete_link (alsa->priv->devices, item);
 
     g_hash_table_remove (alsa->priv->devices_ids,
                          ALSA_DEVICE_GET_ID (device));
 
-    /* The list may and may not have been invalidate by device signals */
+    /* The list may have been invalidated by device signals */
     free_stream_list (alsa);
 
     g_signal_emit_by_name (G_OBJECT (alsa),
