@@ -36,10 +36,8 @@ struct _AlsaTogglePrivate
 
 static void alsa_element_interface_init (AlsaElementInterface *iface);
 
-static void alsa_toggle_class_init      (AlsaToggleClass      *klass);
-static void alsa_toggle_init            (AlsaToggle           *toggle);
-
 G_DEFINE_TYPE_WITH_CODE (AlsaToggle, alsa_toggle, MATE_MIXER_TYPE_STREAM_TOGGLE,
+                         G_ADD_PRIVATE(AlsaToggle)
                          G_IMPLEMENT_INTERFACE (ALSA_TYPE_ELEMENT,
                                                 alsa_element_interface_init))
 
@@ -66,16 +64,12 @@ alsa_toggle_class_init (AlsaToggleClass *klass)
 
     switch_class = MATE_MIXER_SWITCH_CLASS (klass);
     switch_class->set_active_option = alsa_toggle_set_active_option;
-
-    g_type_class_add_private (G_OBJECT_CLASS (klass), sizeof (AlsaTogglePrivate));
 }
 
 static void
 alsa_toggle_init (AlsaToggle *toggle)
 {
-    toggle->priv = G_TYPE_INSTANCE_GET_PRIVATE (toggle,
-                                                ALSA_TYPE_TOGGLE,
-                                                AlsaTogglePrivate);
+    toggle->priv = alsa_toggle_get_instance_private (toggle);
 }
 
 AlsaToggle *
@@ -121,14 +115,14 @@ alsa_toggle_set_active_option (MateMixerSwitch *mms, MateMixerSwitchOption *mmso
 
     toggle = ALSA_TOGGLE (mms);
 
-    if G_UNLIKELY (toggle->priv->element == NULL)
+    if (G_UNLIKELY (toggle->priv->element == NULL))
         return FALSE;
 
     /* For toggles the 0/1 value is stored as the switch option id, there is not really
      * a need to validate that the option belong to the switch, just make sure it
      * contains the value 0 or 1 */
     value = alsa_switch_option_get_id (ALSA_SWITCH_OPTION (mmso));
-    if G_UNLIKELY (value != 0 && value != 1) {
+    if (G_UNLIKELY (value != 0 && value != 1)) {
         g_warn_if_reached ();
         return FALSE;
     }
@@ -176,7 +170,7 @@ alsa_toggle_load (AlsaElement *element)
 
     toggle = ALSA_TOGGLE (element);
 
-    if G_UNLIKELY (toggle->priv->element == NULL)
+    if (G_UNLIKELY (toggle->priv->element == NULL))
         return FALSE;
 
     /* When reading the first time we try all the channels, otherwise only the
