@@ -184,7 +184,7 @@ static void oss_device_init       (OssDevice      *device);
 static void oss_device_dispose    (GObject        *object);
 static void oss_device_finalize   (GObject        *object);
 
-G_DEFINE_TYPE (OssDevice, oss_device, MATE_MIXER_TYPE_DEVICE)
+G_DEFINE_TYPE_WITH_PRIVATE (OssDevice, oss_device, MATE_MIXER_TYPE_DEVICE)
 
 static const GList *oss_device_list_streams       (MateMixerDevice *mmd);
 
@@ -227,16 +227,12 @@ oss_device_class_init (OssDeviceClass *klass)
                       G_TYPE_NONE,
                       0,
                       G_TYPE_NONE);
-
-    g_type_class_add_private (object_class, sizeof (OssDevicePrivate));
 }
 
 static void
 oss_device_init (OssDevice *device)
 {
-    device->priv = G_TYPE_INSTANCE_GET_PRIVATE (device,
-                                                OSS_TYPE_DEVICE,
-                                                OssDevicePrivate);
+    device->priv = oss_device_get_instance_private (device);
 }
 
 static void
@@ -592,7 +588,7 @@ read_mixer_devices (OssDevice *device)
                                           device->priv->fd,
                                           i,
                                           stereo);
-        if G_UNLIKELY (control == NULL)
+        if (G_UNLIKELY (control == NULL))
             continue;
 
         if (oss_stream_has_controls (stream) == FALSE) {
@@ -642,7 +638,7 @@ read_mixer_switch (OssDevice *device)
         options = g_list_prepend (options, option);
     }
 
-    if G_LIKELY (options != NULL)
+    if (G_LIKELY (options != NULL))
         oss_stream_set_switch_data (device->priv->input,
                                     device->priv->fd,
                                     g_list_reverse (options));
@@ -653,7 +649,7 @@ poll_mixer (OssDevice *device)
 {
     gboolean load = TRUE;
 
-    if G_UNLIKELY (device->priv->fd == -1)
+    if (G_UNLIKELY (device->priv->fd == -1))
         return G_SOURCE_REMOVE;
 
 #ifdef SOUND_MIXER_INFO
@@ -711,7 +707,7 @@ poll_mixer (OssDevice *device)
 static gboolean
 poll_mixer_restore (OssDevice *device)
 {
-    if G_LIKELY (device->priv->poll_mode == OSS_POLL_RAPID) {
+    if (G_LIKELY (device->priv->poll_mode == OSS_POLL_RAPID)) {
         /* Remove the current rapid source */
         g_source_remove (device->priv->poll_tag);
 
