@@ -114,16 +114,12 @@ struct _PulseBackendPrivate
         (g_object_steal_data (G_OBJECT (o),                             \
                               "__matemixer_pulse_hanging"))
 
-static void pulse_backend_class_init     (PulseBackendClass *klass);
-static void pulse_backend_class_finalize (PulseBackendClass *klass);
-
-static void pulse_backend_init           (PulseBackend      *pulse);
 static void pulse_backend_dispose        (GObject           *object);
 static void pulse_backend_finalize       (GObject           *object);
 
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wunused-function"
-G_DEFINE_DYNAMIC_TYPE (PulseBackend, pulse_backend, MATE_MIXER_TYPE_BACKEND)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (PulseBackend, pulse_backend, MATE_MIXER_TYPE_BACKEND, 0, G_ADD_PRIVATE_DYNAMIC(PulseBackend))
 #pragma clang diagnostic pop
 
 static gboolean         pulse_backend_open                      (MateMixerBackend *backend);
@@ -252,8 +248,6 @@ pulse_backend_class_init (PulseBackendClass *klass)
     backend_class->list_stored_controls      = pulse_backend_list_stored_controls;
     backend_class->set_default_input_stream  = pulse_backend_set_default_input_stream;
     backend_class->set_default_output_stream = pulse_backend_set_default_output_stream;
-
-    g_type_class_add_private (object_class, sizeof (PulseBackendPrivate));
 }
 
 /* Called in the code generated by G_DEFINE_DYNAMIC_TYPE() */
@@ -265,9 +259,7 @@ pulse_backend_class_finalize (PulseBackendClass *klass)
 static void
 pulse_backend_init (PulseBackend *pulse)
 {
-    pulse->priv = G_TYPE_INSTANCE_GET_PRIVATE (pulse,
-                                               PULSE_TYPE_BACKEND,
-                                               PulseBackendPrivate);
+    pulse->priv = pulse_backend_get_instance_private (pulse);
 
     /* These hash tables store PulseDevice and PulseStream instances */
     pulse->priv->devices =
@@ -354,7 +346,7 @@ pulse_backend_open (MateMixerBackend *backend)
 
     pulse = PULSE_BACKEND (backend);
 
-    if G_UNLIKELY (pulse->priv->connection != NULL) {
+    if (G_UNLIKELY (pulse->priv->connection != NULL)) {
         g_warn_if_reached ();
         return TRUE;
     }
@@ -368,7 +360,7 @@ pulse_backend_open (MateMixerBackend *backend)
     /* No connection attempt is made during the construction of the connection,
      * but it sets up the PulseAudio structures, which might fail in an
      * unlikely case */
-    if G_UNLIKELY (connection == NULL) {
+    if (G_UNLIKELY (connection == NULL)) {
         PULSE_CHANGE_STATE (pulse, MATE_MIXER_STATE_FAILED);
         return FALSE;
     }
@@ -636,7 +628,7 @@ on_connection_state_notify (PulseConnection *connection,
              * is reached. */
             PULSE_CHANGE_STATE (pulse, MATE_MIXER_STATE_CONNECTING);
 
-            if G_UNLIKELY (pulse->priv->connect_tag != 0)
+            if (G_UNLIKELY (pulse->priv->connect_tag != 0))
                 break;
 
             if (pulse_connection_connect (connection, TRUE) == FALSE) {
@@ -793,7 +785,7 @@ on_connection_card_removed (PulseConnection *connection,
     gchar       *name;
 
     device = g_hash_table_lookup (pulse->priv->devices, GUINT_TO_POINTER (index));
-    if G_UNLIKELY (device == NULL)
+    if (G_UNLIKELY (device == NULL))
         return;
 
     name = g_strdup (mate_mixer_device_get_name (MATE_MIXER_DEVICE (device)));
@@ -856,7 +848,7 @@ on_connection_sink_removed (PulseConnection *connection,
     PulseDevice *device;
 
     stream = g_hash_table_lookup (pulse->priv->sinks, GUINT_TO_POINTER (idx));
-    if G_UNLIKELY (stream == NULL)
+    if (G_UNLIKELY (stream == NULL))
         return;
 
     g_object_ref (stream);
@@ -895,10 +887,10 @@ on_connection_sink_input_info (PulseConnection          *connection,
     PulseSink *sink = NULL;
     PulseSink *prev;
 
-    if G_LIKELY (info->sink != PA_INVALID_INDEX)
+    if (G_LIKELY (info->sink != PA_INVALID_INDEX))
         sink = g_hash_table_lookup (pulse->priv->sinks, GUINT_TO_POINTER (info->sink));
 
-    if G_UNLIKELY (sink == NULL) {
+    if (G_UNLIKELY (sink == NULL)) {
         prev = g_hash_table_lookup (pulse->priv->sink_input_map, GUINT_TO_POINTER (info->index));
         if (prev != NULL) {
             g_debug ("Sink input %u moved from sink %s to an unknown sink %u, removing",
@@ -938,7 +930,7 @@ on_connection_sink_input_removed (PulseConnection *connection,
     PulseSink *sink;
 
     sink = g_hash_table_lookup (pulse->priv->sink_input_map, GUINT_TO_POINTER (idx));
-    if G_UNLIKELY (sink == NULL)
+    if (G_UNLIKELY (sink == NULL))
         return;
 
     remove_sink_input (pulse, sink, idx);
@@ -993,7 +985,7 @@ on_connection_source_removed (PulseConnection *connection,
     PulseStream *stream;
 
     stream = g_hash_table_lookup (pulse->priv->sources, GUINT_TO_POINTER (idx));
-    if G_UNLIKELY (stream == NULL)
+    if (G_UNLIKELY (stream == NULL))
         return;
 
     g_object_ref (stream);
@@ -1032,10 +1024,10 @@ on_connection_source_output_info (PulseConnection             *connection,
     PulseSource *source = NULL;
     PulseSource *prev;
 
-    if G_LIKELY (info->source != PA_INVALID_INDEX)
+    if (G_LIKELY (info->source != PA_INVALID_INDEX))
         source = g_hash_table_lookup (pulse->priv->sources, GUINT_TO_POINTER (info->source));
 
-    if G_UNLIKELY (source == NULL) {
+    if (G_UNLIKELY (source == NULL)) {
         prev = g_hash_table_lookup (pulse->priv->source_output_map, GUINT_TO_POINTER (info->index));
         if (prev != NULL) {
             g_debug ("Source output %u moved from source %s to an unknown source %u, removing",
@@ -1075,7 +1067,7 @@ on_connection_source_output_removed (PulseConnection *connection,
     PulseSource *source;
 
     source = g_hash_table_lookup (pulse->priv->source_output_map, GUINT_TO_POINTER (idx));
-    if G_UNLIKELY (source == NULL)
+    if (G_UNLIKELY (source == NULL))
         return;
 
     remove_source_output (pulse, source, idx);
