@@ -49,8 +49,6 @@ enum {
 
 static GParamSpec *properties[N_PROPERTIES] = { NULL, };
 
-static void pulse_ext_stream_class_init   (PulseExtStreamClass *klass);
-
 static void pulse_ext_stream_get_property (GObject             *object,
                                            guint                param_id,
                                            GValue              *value,
@@ -60,11 +58,10 @@ static void pulse_ext_stream_set_property (GObject             *object,
                                            const GValue        *value,
                                            GParamSpec          *pspec);
 
-static void pulse_ext_stream_init         (PulseExtStream      *ext);
 static void pulse_ext_stream_dispose      (GObject             *object);
 static void pulse_ext_stream_finalize     (GObject             *object);
 
-G_DEFINE_TYPE (PulseExtStream, pulse_ext_stream, MATE_MIXER_TYPE_STORED_CONTROL)
+G_DEFINE_TYPE_WITH_PRIVATE (PulseExtStream, pulse_ext_stream, MATE_MIXER_TYPE_STORED_CONTROL)
 
 static MateMixerAppInfo *       pulse_ext_stream_get_app_info         (MateMixerStreamControl  *mmsc);
 
@@ -159,8 +156,6 @@ pulse_ext_stream_class_init (PulseExtStreamClass *klass)
                             G_PARAM_STATIC_STRINGS);
 
     g_object_class_install_properties (object_class, N_PROPERTIES, properties);
-
-    g_type_class_add_private (object_class, sizeof (PulseExtStreamPrivate));
 }
 
 static void
@@ -214,9 +209,7 @@ pulse_ext_stream_set_property (GObject      *object,
 static void
 pulse_ext_stream_init (PulseExtStream *ext)
 {
-    ext->priv = G_TYPE_INSTANCE_GET_PRIVATE (ext,
-                                             PULSE_TYPE_EXT_STREAM,
-                                             PulseExtStreamPrivate);
+    ext->priv = pulse_ext_stream_get_instance_private (ext);
 }
 
 static void
@@ -286,7 +279,7 @@ pulse_ext_stream_new (PulseConnection                  *connection,
         suffix++;
 
     if (strstr (info->name, "-by-media-role:")) {
-        if G_LIKELY (suffix != NULL)
+        if (G_LIKELY (suffix != NULL))
             media_role = pulse_convert_media_role_name (suffix);
     }
     else if (strstr (info->name, "-by-application-name:")) {
@@ -298,7 +291,7 @@ pulse_ext_stream_new (PulseConnection                  *connection,
         if (app_info == NULL)
             app_info = _mate_mixer_app_info_new ();
 
-        if G_LIKELY (suffix != NULL)
+        if (G_LIKELY (suffix != NULL))
             _mate_mixer_app_info_set_name (app_info, suffix);
     }
     else if (strstr (info->name, "-by-application-id:")) {
@@ -310,7 +303,7 @@ pulse_ext_stream_new (PulseConnection                  *connection,
         if (app_info == NULL)
             app_info = _mate_mixer_app_info_new ();
 
-        if G_LIKELY (suffix != NULL)
+        if (G_LIKELY (suffix != NULL))
             _mate_mixer_app_info_set_id (app_info, suffix);
     }
 
