@@ -43,12 +43,10 @@ struct _PulseSourcePrivate
     PulseSourceControl *control;
 };
 
-static void pulse_source_class_init (PulseSourceClass *klass);
-static void pulse_source_init       (PulseSource      *source);
 static void pulse_source_dispose    (GObject          *object);
 static void pulse_source_finalize   (GObject          *object);
 
-G_DEFINE_TYPE (PulseSource, pulse_source, PULSE_TYPE_STREAM);
+G_DEFINE_TYPE_WITH_PRIVATE (PulseSource, pulse_source, PULSE_TYPE_STREAM);
 
 static const GList *pulse_source_list_controls (MateMixerStream *mms);
 static const GList *pulse_source_list_switches (MateMixerStream *mms);
@@ -68,16 +66,12 @@ pulse_source_class_init (PulseSourceClass *klass)
     stream_class = MATE_MIXER_STREAM_CLASS (klass);
     stream_class->list_controls = pulse_source_list_controls;
     stream_class->list_switches = pulse_source_list_switches;
-
-    g_type_class_add_private (klass, sizeof (PulseSourcePrivate));
 }
 
 static void
 pulse_source_init (PulseSource *source)
 {
-    source->priv = G_TYPE_INSTANCE_GET_PRIVATE (source,
-                                                PULSE_TYPE_SOURCE,
-                                                PulseSourcePrivate);
+    source->priv = pulse_source_get_instance_private (source);
 
     source->priv->outputs = g_hash_table_new_full (g_direct_hash,
                                                    g_direct_equal,
@@ -226,7 +220,7 @@ pulse_source_remove_output (PulseSource *source, guint32 index)
     g_return_if_fail (PULSE_IS_SOURCE (source));
 
     output = g_hash_table_lookup (source->priv->outputs, GUINT_TO_POINTER (index));
-    if G_UNLIKELY (output == NULL)
+    if (G_UNLIKELY (output == NULL))
         return;
 
     name = g_strdup (mate_mixer_stream_control_get_name (MATE_MIXER_STREAM_CONTROL (output)));
