@@ -58,10 +58,6 @@ enum {
 
 static guint signals[N_SIGNALS] = { 0, };
 
-static void mate_mixer_backend_class_init   (MateMixerBackendClass *klass);
-
-static void mate_mixer_backend_init         (MateMixerBackend      *backend);
-
 static void mate_mixer_backend_get_property (GObject               *object,
                                              guint                  param_id,
                                              GValue                *value,
@@ -74,7 +70,7 @@ static void mate_mixer_backend_set_property (GObject               *object,
 static void mate_mixer_backend_dispose      (GObject               *object);
 static void mate_mixer_backend_finalize     (GObject               *object);
 
-G_DEFINE_ABSTRACT_TYPE (MateMixerBackend, mate_mixer_backend, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (MateMixerBackend, mate_mixer_backend, G_TYPE_OBJECT)
 
 static void device_added          (MateMixerBackend *backend,
                                    const gchar      *name);
@@ -195,8 +191,6 @@ mate_mixer_backend_class_init (MateMixerBackendClass *klass)
                       G_TYPE_NONE,
                       1,
                       G_TYPE_STRING);
-
-    g_type_class_add_private (object_class, sizeof (MateMixerBackendPrivate));
 }
 
 static void
@@ -253,9 +247,7 @@ mate_mixer_backend_set_property (GObject      *object,
 static void
 mate_mixer_backend_init (MateMixerBackend *backend)
 {
-    backend->priv = G_TYPE_INSTANCE_GET_PRIVATE (backend,
-                                                 MATE_MIXER_TYPE_BACKEND,
-                                                 MateMixerBackendPrivate);
+    backend->priv = mate_mixer_backend_get_instance_private (backend);
 
     backend->priv->devices = g_hash_table_new_full (g_str_hash,
                                                     g_str_equal,
@@ -537,7 +529,7 @@ device_added (MateMixerBackend *backend, const gchar *name)
     MateMixerDevice *device;
 
     device = mate_mixer_backend_get_device (backend, name);
-    if G_UNLIKELY (device == NULL) {
+    if (G_UNLIKELY (device == NULL)) {
         g_warn_if_reached ();
         return;
     }
@@ -566,7 +558,7 @@ device_removed (MateMixerBackend *backend, const gchar *name)
     MateMixerDevice *device;
 
     device = g_hash_table_lookup (backend->priv->devices, name);
-    if G_UNLIKELY (device == NULL) {
+    if (G_UNLIKELY (device == NULL)) {
         g_warn_if_reached ();
         return;
     }
