@@ -61,8 +61,6 @@ enum {
 
 static guint signals[N_SIGNALS] = { 0, };
 
-static void mate_mixer_device_class_init   (MateMixerDeviceClass *klass);
-
 static void mate_mixer_device_get_property (GObject              *object,
                                             guint                 param_id,
                                             GValue               *value,
@@ -72,10 +70,9 @@ static void mate_mixer_device_set_property (GObject              *object,
                                             const GValue         *value,
                                             GParamSpec           *pspec);
 
-static void mate_mixer_device_init         (MateMixerDevice      *device);
 static void mate_mixer_device_finalize     (GObject              *object);
 
-G_DEFINE_ABSTRACT_TYPE (MateMixerDevice, mate_mixer_device, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (MateMixerDevice, mate_mixer_device, G_TYPE_OBJECT)
 
 static MateMixerStream *      mate_mixer_device_real_get_stream (MateMixerDevice *device,
                                                                  const gchar     *name);
@@ -229,8 +226,6 @@ mate_mixer_device_class_init (MateMixerDeviceClass *klass)
                       G_TYPE_NONE,
                       1,
                       G_TYPE_STRING);
-
-    g_type_class_add_private (object_class, sizeof (MateMixerDevicePrivate));
 }
 
 static void
@@ -293,9 +288,7 @@ mate_mixer_device_set_property (GObject      *object,
 static void
 mate_mixer_device_init (MateMixerDevice *device)
 {
-    device->priv = G_TYPE_INSTANCE_GET_PRIVATE (device,
-                                                MATE_MIXER_TYPE_DEVICE,
-                                                MateMixerDevicePrivate);
+    device->priv = mate_mixer_device_get_instance_private (device);
 }
 
 static void
@@ -434,7 +427,7 @@ mate_mixer_device_list_streams (MateMixerDevice *device)
 
     klass = MATE_MIXER_DEVICE_GET_CLASS (device);
 
-    if G_LIKELY (klass->list_streams != NULL)
+    if (G_LIKELY (klass->list_streams != NULL))
         return klass->list_streams (device);
 
     return NULL;
@@ -468,7 +461,7 @@ mate_mixer_device_list_switches (MateMixerDevice *device)
 
     klass = MATE_MIXER_DEVICE_GET_CLASS (device);
 
-    if G_LIKELY (klass->list_switches != NULL)
+    if (G_LIKELY (klass->list_switches != NULL))
         return klass->list_switches (device);
 
     return NULL;
