@@ -66,8 +66,6 @@ enum {
 
 static guint signals[N_SIGNALS] = { 0, };
 
-static void mate_mixer_stream_control_class_init   (MateMixerStreamControlClass *klass);
-
 static void mate_mixer_stream_control_get_property (GObject                     *object,
                                                     guint                        param_id,
                                                     GValue                      *value,
@@ -77,10 +75,9 @@ static void mate_mixer_stream_control_set_property (GObject
                                                     const GValue                *value,
                                                     GParamSpec                  *pspec);
 
-static void mate_mixer_stream_control_init         (MateMixerStreamControl      *control);
 static void mate_mixer_stream_control_finalize     (GObject                     *object);
 
-G_DEFINE_ABSTRACT_TYPE (MateMixerStreamControl, mate_mixer_stream_control, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (MateMixerStreamControl, mate_mixer_stream_control, G_TYPE_OBJECT)
 
 static void
 mate_mixer_stream_control_class_init (MateMixerStreamControlClass *klass)
@@ -200,8 +197,6 @@ mate_mixer_stream_control_class_init (MateMixerStreamControlClass *klass)
                       G_TYPE_NONE,
                       1,
                       G_TYPE_DOUBLE);
-
-    g_type_class_add_private (object_class, sizeof (MateMixerStreamControlPrivate));
 }
 
 static void
@@ -286,9 +281,7 @@ mate_mixer_stream_control_set_property (GObject      *object,
 static void
 mate_mixer_stream_control_init (MateMixerStreamControl *control)
 {
-    control->priv = G_TYPE_INSTANCE_GET_PRIVATE (control,
-                                                 MATE_MIXER_TYPE_STREAM_CONTROL,
-                                                 MateMixerStreamControlPrivate);
+    control->priv = mate_mixer_stream_control_get_instance_private (control);
 }
 
 static void
